@@ -5,13 +5,13 @@
  * CopyRight 2002 S.YOSHIMURA GPL2
  * http://masui.net/pukiwiki/ yosimura@excellence.ac.jp
  *
- * $Id: versionlist.inc.php,v 1.2 2002/12/05 05:45:18 panda Exp $
+ * $Id: versionlist.inc.php,v 1.2.2.2 2004/04/03 17:49:35 arino Exp $
  */
 
 function plugin_versionlist_convert()
 {
   global $vars, $script;
-  $SCRIPT_DIR = array("./","./plugin/");
+  $SCRIPT_DIR = array("./","./plugin/","./skin/");
   /* õǥ쥯ȥꡣϡpukiwiki.ini.php  */
 
   if(func_num_args())
@@ -25,7 +25,7 @@ function plugin_versionlist_convert()
     if ($dir = @dir($sdir)){
       while($file = $dir->read()){
         if($file == ".." || $file == ".") continue;
-        if(!preg_match('/\.php$/i',$file)) continue;
+        if(!preg_match("/\.(php|lng|css|js)$/i",$file)) continue;
         
         $comment = '';
         $filenp = $sdir . $file;
